@@ -151,8 +151,7 @@ NNS.VAR <- function(variables,
   }
   
   if(num_cores > 1){
-    cl <- parallel::makeCluster(num_cores)
-    doParallel::registerDoParallel(cl)
+    doParallel::registerDoParallel(num_cores)
     invisible(data.table::setDTthreads(1))
   } else {
     foreach::registerDoSEQ()
@@ -167,7 +166,6 @@ NNS.VAR <- function(variables,
   
   
   nns_IVs <- foreach(i = 1:ncol(variables), .packages = c("NNS", "data.table"))%dopar%{
-    #  for(i in 1:ncol(variables)){
     n <- nrow(variables)
     index <- seq_len(n)
     last_point <- n
@@ -341,8 +339,6 @@ NNS.VAR <- function(variables,
                    }
   
   if(num_cores > 1) {
-    parallel::stopCluster(cl)
-    remove(cl)
     foreach::registerDoSEQ()
     invisible(data.table::setDTthreads(0, throttle = NULL))
   }
@@ -361,8 +357,7 @@ NNS.VAR <- function(variables,
   RV <- do.call(cbind, lapply(RV, `length<-`, max(lengths(RV))))
   colnames(RV) <- as.character(colnames(variables))
   
-  uni <- numeric(length(colnames(RV)))
-  multi <- numeric(length(colnames(RV)))
+  multi <- uni <- numeric(length(colnames(RV)))
   
   for(i in 1:length(colnames(RV))){
     if(length(na.omit(RV[,i]) > 0)){
@@ -372,30 +367,13 @@ NNS.VAR <- function(variables,
       equal_tau <- sum(given_var==observed_var)
       unequal_tau <- sum(given_var!=observed_var)
       
-      if(equal_tau > unequal_tau) uni[i] <-  .5 + .5*((equal_tau)/(equal_tau + unequal_tau)) else uni[i] <-  .5 - .5*((unequal_tau)/(equal_tau + unequal_tau))
-      
-      if(equal_tau == unequal_tau) uni[i] <- 0.5
-      
-      uni[i] <- (uni[i] + 0.5)/2
-      
+      uni[i] <-  mean(c(.5, equal_tau/(equal_tau + unequal_tau)))
       multi[i] <- 1 - uni[i]
+      
     } else {
       uni[i] <- 0.5
       multi[i] <- 0.5
     }
-    
-    if(abs(uni[i]) > 1){
-      uni[i] <- abs(uni[i])/(abs(uni[i]) + abs(multi[i]))
-      uni[i] <- (uni[i] + 0.5)/2
-      multi[i] <- 1 - uni[i]
-    }
-    
-    if(all((diff(nns_DVs[,i])/nns_DVs[-1,i])<1e-5)){
-      uni[i] <- 1
-      multi[i] <- 0
-    }
-    
-    uni[i] <- multi[i] <- .5
   }
   
 
