@@ -1,5 +1,10 @@
-## ----setup, include=FALSE-----------------------------------------------------
+## ----setup, include=FALSE, message=FALSE--------------------------------------
 knitr::opts_chunk$set(echo = TRUE)
+library(NNS)
+library(data.table)
+data.table::setDTthreads(2L)
+options(mc.cores = 1)
+Sys.setenv("OMP_THREAD_LIMIT" = 2)
 
 ## ----setup2, message=FALSE, warning=FALSE-------------------------------------
 library(NNS)
@@ -60,7 +65,8 @@ NNS.reg(iris[ , 1 : 4], iris[ , 5], type = "CLASS", point.est = iris[1 : 10, 1 :
 
 ## ----stackevalres, eval = FALSE-----------------------------------------------
 #  Folds Remaining = 0
-#  Current NNS.reg(... , threshold = 0.79 ) MAX Iterations Remaining = 1
+#  Current NNS.reg(... , threshold = 0.935 ) MAX Iterations Remaining = 2
+#  Current NNS.reg(... , threshold = 0.795 ) MAX Iterations Remaining = 1
 #  Current NNS.reg(... , threshold = 0.44 ) MAX Iterations Remaining = 0
 #  Current NNS.reg(... , n.best = 1 ) MAX Iterations Remaining = 12
 #  Current NNS.reg(... , n.best = 2 ) MAX Iterations Remaining = 11
@@ -73,28 +79,28 @@ NNS.reg(iris[ , 1 : 4], iris[ , 5], type = "CLASS", point.est = iris[1 : 10, 1 :
 #  [1] 1
 #  
 #  $probability.threshold
-#  [1] 0.445
+#  [1] 0.43875
 #  
 #  $OBJfn.dim.red
-#  [1] 0.9133333
+#  [1] 0.9666667
 #  
 #  $NNS.dim.red.threshold
-#  [1] 0.79
+#  [1] 0.935
 #  
 #  $reg
-#  [1] 1 1 1 1 1 1 1 1 1 1
+#   [1] 1 1 1 1 1 1 1 1 1 1
 #  
 #  $reg.pred.int
 #  NULL
 #  
 #  $dim.red
-#  [1] 1 1 1 1 1 1 1 1 1 1
+#   [1] 1 1 1 1 1 1 1 1 1 1
 #  
 #  $dim.red.pred.int
 #  NULL
 #  
 #  $stack
-#  [1] 1 1 1 1 1 1 1 1 1 1
+#   [1] 1 1 1 1 1 1 1 1 1 1
 #  
 #  $pred.int
 #  NULL
