@@ -81,6 +81,14 @@ Co.LPM(0, x, y, 0, 0)
 # Vectorized targets:
 Co.LPM(0, x, y, c(0, 1), c(0, 1))
 
+# Copula
+# Transform x and y so that they are uniform
+u_x = LPM.ratio(0, x, x)
+u_y = LPM.ratio(0, y, y)
+
+# Value of copula at c(.5, .5)
+Co.LPM(0, u_x, u_y, .5, .5)
+
 # Continuous CDF:
 NNS.CDF(x, 1)
 
